
# This file was generated by 'versioneer.py' (0.17) from
# revision-control system data, or from the parent directory name of an
# unpacked source archive. Distribution tarballs contain a pre-generated copy
# of this file.

import json

version_json = '''
{
 "date": "2019-11-20T15:51:52-0800",
 "dirty": false,
 "error": null,
 "full-revisionid": "f4e571feea0759255db1c7dcdc5ff2fe8f81d200",
 "version": "v0.16.2"
}
'''  # END VERSION_JSON


def get_versions():
    return json.loads(version_json)
